from django.shortcuts import render
from .forms import ExampleForm


def upload_view(request):
    if request.method == "POST":
        form = ExampleForm(request.POST, request.FILES)
        if form.is_valid():
            # Retrieve files from each field
            image_single = request.FILES.get("image_single")
            image_multiple = request.FILES.getlist("image_multiple")
            file_single = request.FILES.get("file_single")
            file_multiple = request.FILES.getlist("file_multiple")

            # Combine all uploaded files into a single list
            uploaded_files = []
            if image_single:
                uploaded_files.append(image_single)
            uploaded_files.extend(image_multiple)
            if file_single:
                uploaded_files.append(file_single)
            uploaded_files.extend(file_multiple)

            return render(
                request, "example_app/success.html", {"files": uploaded_files}
            )
    else:
        form = ExampleForm()
    return render(request, "example_app/upload.html", {"form": form})



from django import forms
from django.utils.translation import get_language


class FilePondWidget(forms.ClearableFileInput):
    template_name = "django_filepond_form_widget/filepond_widget.html"

    def __init__(self, attrs=None, config=None):
        # app .filepond-input to the widget attrs class
        if attrs is None:
            attrs = {}
        attrs["class"] = "filepond-input"

        super().__init__(attrs)
        self.config = config or {}
        self.config["storeAsFile"] = True

    @property
    def media(self):
        css = {"all": ["django_filepond_form_widget/css/filepond.min.css"]}
        js = ["django_filepond_form_widget/js/filepond.min.js"]

        if self.config.get("allowImagePreview"):
            css["all"].append(
                "django_filepond_form_widget/css/filepond-plugin-image-preview.min.css"
            )
            js.append(
                "django_filepond_form_widget/js/filepond-plugin-image-preview.min.js"
            )

        js.append("django_filepond_form_widget/js/init_filepond.js")

        return forms.Media(css=css, js=js)

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)
        context["widget"]["filepond_config"] = self.config
        context["widget"]["locale"] = get_language()
        context["widget"]["filepond_config_id"] = (
            f"filepond_config_{context['widget']['attrs']['id']}"
        )
        return context



from django import forms
from django_filepond_form_widget.widgets import FilePondWidget


class ExampleForm(forms.Form):
    image_single = forms.FileField(
        widget=FilePondWidget(
            config={"allowImagePreview": True, "allowMultiple": False}
        )
    )
    image_multiple = forms.FileField(
        widget=FilePondWidget(config={"allowImagePreview": True, "allowMultiple": True})
    )
    file_single = forms.FileField(
        widget=FilePondWidget(
            config={"allowImagePreview": False, "allowMultiple": False}
        )
    )
    file_multiple = forms.FileField(
        widget=FilePondWidget(
            config={"allowImagePreview": False, "allowMultiple": True}
        )
    )
